Learn R Programming

movieROC (version 0.1.1)

gROC_param: Build a binormal ROC curve for a univariate marker

Description

This function builds a univariate ROC curve (standard or general) assuming the binormal scenario with parameters being the sample estimates. It returns a ‘groc’ object, a list of class ‘groc’.

Usage

gROC_param(X, D, side = c("right", "left", "both", "both2"), N = NULL, ...)

Value

A list of class ‘groc’ with the following fields:

controls, cases

Marker values of negative and positive subjects, respectively.

levels

Levels of response values.

side

Type of ROC curve.

t

Vector of false-positive rates.

roc

Vector of values of the ROC curve for t.

c

Vector of marker thresholds resulting in (t, roc) if side = "right" | "left".

xl, xu

Vectors of marker thresholds resulting in (t, roc) if side = "both" | "both2".

auc

Area under the curve estimate.

a, b

Estimates for parameters \(a\) and \(b\) considered for the ROC curve estimation: \(\hat{a} = \left[ \overline{\xi_n} - \overline{\chi_m} \right]/\hat{s}_\xi\) and \(\hat{b} = \hat{s}_\chi / \hat{s}_\xi\).

p0

Estimate of the "central value", \(\mu^*\), about to which the thresholds \(x^L\) and \(x^U\) are symmetrical.

Arguments

X

Vector of marker values.

D

Vector of response values. Two levels; if more, the two first ones are used.

side

Type of ROC curve. One of "right" (\(\mathcal{R}_r(\cdot)\)), "left" (\(\mathcal{R}_l(\cdot)\)), "both" (\(\mathcal{R}_g(\cdot)\)) or "both2" (\(\mathcal{R}_{g'}(\cdot)\)). Default: "right".

N

Number indicating the length of the vector of FPR considered to build the ROC curve: \(t \in \{ 0, 1/N, 2/N, \dots, 1 \}\). Default: 1000.

...

Other parameters to be passed. Not used.

Details

This function's main job is to estimate an ROC curve for a univariate marker under one of these considerations: larger values of the marker are associated with a higher probability of being positive (resulting in the right-sided ROC curve, \(\mathcal{R}_r (\cdot)\)), the opposite (left-sided ROC curve, \(\mathcal{R}_l (\cdot)\)), when both smaller and larger values of the marker are associated with having more probability of being positive (gROC curve, \(\mathcal{R}_g(\cdot)\)), the opposite (opposite gROC curve, \(\mathcal{R}_{g'}(\cdot)\)).

References

P. Martínez-Camblor and J. C. Pardo-Fernández (2019) ``Parametric estimates for the receiver operating characteristic curve generalization for non-monotone relationships''. Statistical Methods in Medical Research, 28(7): 2032–2048. DOI: tools:::Rd_expr_doi("10.1177/0962280217747009").

Examples

Run this code
data(HCC)

# ROC curve estimates for gene 03515901 and response tumor assuming the binormal scenario
gROC_param(X = HCC[,"cg03515901"], D = HCC$tumor) # Standard right-sided ROC curve
gROC_param(X = HCC[,"cg03515901"], D = HCC$tumor, side = "left") # Left-sided ROC curve 
gROC_param(X = HCC[,"cg03515901"], D = HCC$tumor, side = "both") # gROC curve 

Run the code above in your browser using DataLab