This function tracks the construction of the standard ROC curve (right- or left-sided, depending on the side of the object of class ‘groc’ included) resulting from the kernel density function estimation for controls and cases. Four graphics are displayed: top-left, the kernel density estimates; top-right, the resulting ROC curve; bottom-left, boxplots and points for controls and cases and classification subset in gray color; bottom-right, classification subsets for every FPR until the current one. It makes use of the plot_densityROC() function for each screenshot.
movieROC2_densities(obj, h = c(1, 1), cut.off = NULL, completeROC = FALSE,
legends = FALSE, videobar = TRUE, file = "animation1.gif", clean = FALSE,
interval = 0.2, ani.width = 500, ani.height = 750, save = TRUE,
tpause = 1, verbose = FALSE, ...)A video with the building procedure of the smooth ROC curve estimate with the selected graphical parameters
An object of class ‘groc’ with side = "right" or "left".
A vector of length 2 with the bandwidth used to compute kernel density estimation for controls and cases, respectively. See adjust parameter in density() function from stats package. Default: h = c(1,1).
Vector with marker cutoffs for which the graphics are displayed. Default: if number of unique marker values is lower than 150, these are considered; otherwise, a equally-spaced grid of length 102 in the range of the marker is used.
If TRUE, video is saved as a GIF by using the saveGIF() function in animation package. Default: TRUE.
A logical value indicating if the whole ROC curve should be displayed in light gray or not. Default: FALSE.
If TRUE, legends with the meaning of colors are displayed. Default: FALSE.
If TRUE, a text progress bar is shown in the R console. Default: TRUE.
File name of the movie (with the extension). Default: "animation1.gif".
Whether to delete the individual image frames in animation package. Default: FALSE.
A positive number to set the time interval of the animation (unit in seconds) in animation package. Default: 0.2.
Width and height of image frames (unit in px) in animation package.
If save = FALSE, time interval to suspend execution for, in seconds. Default: 1.
If TRUE, a progress bar is displayed for computationally intensive methods. Default: FALSE.
Other parameters to be passed to the saveGIF function in animation package.
If save = TRUE (by default), the saveGIF() function in the animation package is used.
data(HCC)
# Standard ROC curve for gene 20202438
roc_cg20202438 <- gROC(X = HCC$cg20202438, D = HCC$tumor)
# \donttest{
### The video will be saved as a GIF with the name "video_cg20202438_smooth"
movieROC2_densities(roc_cg20202438, file = "video_cg20202438_smooth.gif", save = FALSE)# }
Run the code above in your browser using DataLab